Function rune_native::rune_output_tensor_as_fixed
source · [−]#[no_mangle]
pub unsafe extern "C" fn rune_output_tensor_as_fixed(
tensor: *const OutputTensor
) -> *const TensorExpand description
Get a reference to the underlying Tensor if this output tensor has a fixed
size.
This will return null if the OutputTensor contains dynamically sized
data (i.e. strings) or if the tensor parameter is null.
Safety
This inherits all the safety requirements from OutputTensors, with the
added condition that you must not mutate the tensor’s data through this
pointer.